@@ -7,44 +7,44 @@ use strict;
 use utf8;
 use base 'POD2::Base';
 
-our $VERSION = '5.18.0.1.83';
+our $VERSION = '5.18.0.1.84';
 
 # Versions list
 sub pod_info {
-    'a2p.pod'               => '5.18.0.1',
-      'perlbook.pod'        => '5.18.0.1',
-      'perlcheat.pod'       => '5.18.0.1',
-      'perldebtut.pod'      => '5.18.0.1',
-      'perldoc.pod'         => '5.18.0.1',
-      'perlguts.pod'        => '5.18.0.1',
-      'perlhacktut.pod'     => '5.18.0.1',
-      'perlintro.pod'       => '5.18.0.1',
-      'perlmod.pod'         => '5.18.0.1',
-      'perlnewmod.pod'      => '5.18.0.1',
-      'perlootut.pod'       => '5.18.0.1',
-      'perlopentut.pod'     => '5.18.0.1',
-      'perlpacktut.pod'     => '5.18.0.1',
-      'perl.pod'            => '5.18.0.1',
-      'perlpod.pod'         => '5.18.0.1',
-      'perlpodspec.pod'     => '5.18.0.1',
-      'perlpodstyle.pod'    => '5.18.0.1',
-      'perlpragma.pod'      => '5.18.0.1',
-      'perlreapi.pod'       => '5.18.0.1',
-      'perlrebackslash.pod' => '5.18.0.1',
-      'perlrecharclass.pod' => '5.18.0.1',
-      'perlreftut.pod'      => '5.18.0.1',
-      'perlreguts.pod'      => '5.18.0.1',
-      'perlre.pod'          => '5.18.0.1',
-      'perlrequick.pod'     => '5.18.0.1',
-      'perlreref.pod'       => '5.18.0.1',
-      'perlretut.pod'       => '5.18.0.1',
-      'perlrun.pod'         => '5.18.0.1',
-      'perlsecret.pod'      => '5.18.0.1',
-      'perlstyle.pod'       => '5.18.0.1',
-      'perlthrtut.pod'      => '5.18.0.1',
-      'perlunicode.pod'     => '5.18.0.1',
-      'perluniintro.pod'    => '5.18.0.1',
-      'perlunitut.pod'      => '5.18.0.1',
+    'a2p.pod'               => '5.18.0',
+      'perlbook.pod'        => '5.18.0',
+      'perlcheat.pod'       => '5.18.0',
+      'perldebtut.pod'      => '5.18.0',
+      'perldoc.pod'         => '5.18.0',
+      'perlguts.pod'        => '5.18.0',
+      'perlhacktut.pod'     => '5.18.0',
+      'perlintro.pod'       => '5.18.0',
+      'perlmod.pod'         => '5.18.0',
+      'perlnewmod.pod'      => '5.18.0',
+      'perlootut.pod'       => '5.18.0',
+      'perlopentut.pod'     => '5.18.0',
+      'perlpacktut.pod'     => '5.18.0',
+      'perl.pod'            => '5.18.0',
+      'perlpod.pod'         => '5.18.0',
+      'perlpodspec.pod'     => '5.18.0',
+      'perlpodstyle.pod'    => '5.18.0',
+      'perlpragma.pod'      => '5.18.0',
+      'perlreapi.pod'       => '5.18.0',
+      'perlrebackslash.pod' => '5.18.0',
+      'perlrecharclass.pod' => '5.18.0',
+      'perlreftut.pod'      => '5.18.0',
+      'perlreguts.pod'      => '5.18.0',
+      'perlre.pod'          => '5.18.0',
+      'perlrequick.pod'     => '5.18.0',
+      'perlreref.pod'       => '5.18.0',
+      'perlretut.pod'       => '5.18.0',
+      'perlrun.pod'         => '5.18.0',
+      'perlsecret.pod'      => '5.18.0',
+      'perlstyle.pod'       => '5.18.0',
+      'perlthrtut.pod'      => '5.18.0',
+      'perlunicode.pod'     => '5.18.0',
+      'perluniintro.pod'    => '5.18.0',
+      'perlunitut.pod'      => '5.18.0',
       ;
 }
 
